# Functions for use in Physics 201/202 at Christopher Newport University

## Required packages

<p> Numpy, Matplotlib, Scipy, Sklearn </p>

## Functions

<p>This module contains the following functions:</p>

<p>constant_fit_plot()</p>

<p>constant_fit_plot_errors()</p>

<p>linear_fit_plot()</p>
<p>linear_fit_plot_errors()</p>

<p>quadratic_fit_plot()</p>
<p>quadratic_fit_plot_errors()</p>

<p>weighted_average()</p>
<p>set_dark_mode()</p>

<p>More information on each of these functions are included in their function-specific docstrings, for example:</p >

<p> import P201_Functions as p201 </p>
<p> print (p201.linear_fit_plot_errors.__doc__) </p>
